@@ -6,7 +6,7 @@ use Carp;
 use Forks::Super::Debug ':all';
 use Forks::Super::Util ':all';
 
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 my $emulate_id = 0;
 
@@ -19,8 +19,6 @@ sub emulate {
     local $Forks::Super::Job::Ipc::USE_TIE_SH = 0;
     local $Forks::Super::Job::Ipc::USE_TIE_PH = 0;
 
-    local $Forks::Super::SIG{CHLD} = undef;
-    
     $_->() for @Forks::Super::Jobs::POSTFORK_CHILD;
     if (!$job->{cmd} && !$job->{exec} && !$job->{sub}) {
         croak "FSJ::Emulate: must use cmd/exec/sub option with emulate";
@@ -51,11 +49,8 @@ sub emulate {
         }
         Forks::Super::Job::Ipc::_child_share($job);
         delete $job->{is_child};
-#       Forks::Super::Job::Ipc::_close_child_fh($job);
     }
     $job->_postlaunch_parent2;
-#    print STDERR "\n----------\n",$job->toString,"\n-----------------\n";
-
     $_->() for @Forks::Super::Jobs::POSTFORK_PARENT;
     return $job;
 }
@@ -80,8 +75,9 @@ sub _postlaunch_child_to_cmd {
 	$c1 = Forks::Super::Job::OS::Win32::system1_win32_process(
 	                      $job, @{$job->{cmd}});
 
-    } else {
+    } elsif (1) {
 
+        our %EMULATE_PID;
 	my $this_pid = $$;
         my $retries = $job->{retries} || 0;
 	my $exec_pid = Forks::Super::Job::_CORE_fork();
@@ -95,11 +91,12 @@ sub _postlaunch_child_to_cmd {
             croak "Forks::Super::Job::_postlaunch_child_to_cmd: ",
                 "Child process unable to create new fork to run cmd";
         }
+        $EMULATE_PID{$exec_pid} = $job;
         if ($$ != $this_pid) {
             exec( @{$job->{cmd}} ) or
                 Carp::confess 'exec for cmd-style fork failed ';
         }
-        $job->{debug} && debug("  exec pid is $exec_pid");
+        $job->{debug} && debug("  exec pid is $exec_pid for job $job");
         $job->set_signal_pid($exec_pid);
         $job->{exec_pid} = $exec_pid;
 
@@ -107,16 +104,21 @@ sub _postlaunch_child_to_cmd {
         # XXX - do something with this in _cleanup_child?
 
         my $z = CORE::waitpid $exec_pid, 0;
-        $c1 = $?;
-        debug("waitpid returned $z, exit code of $$ was $c1 ", $c1>>8)
-            if $job->{debug};
-    }
-    if ($job->{is_emulation}) {
+        if ($z == $exec_pid) {
+            # reaped here
+            $c1 = $?;
+            Forks::Super::Job::Ipc::_close_child_fh($job);
+            Forks::Super::Sigchld::_preliminary_reap($job,$c1);
+            debug("waitpid returned $z, exit code of $$ was $c1 ", $c1>>8)
+                if $job->{debug};
+        } elsif ($job->{debug}) {
+            # not reaped here
+            debug("$$ was reaped in SIGCHLD handler status=$job->{status}");
+        }
+    } else {
+        $c1 = system( @{$job->{cmd}} );
         Forks::Super::Job::Ipc::_close_child_fh($job);
         Forks::Super::Sigchld::_preliminary_reap($job,$c1);
-    } else {
-        Forks::Super::Job::deinit_child();
-        exit $c1 >> 8;
     }
 }
 
@@ -134,7 +136,7 @@ Forks::Super::Job::Emulate - support emulation mode for Job object
 
 =head1 VERSION
 
-0.82
+0.83
 
 =head1 DESCRIPTION
 
