@@ -14,7 +14,7 @@ use warnings;
 our ($_SIGCHLD, $_SIGCHLD_CNT, $REAP) = (0,0,0);
 our (@CHLD_HANDLE_HISTORY, @SIGCHLD_CAUGHT) = (0);
 our $SIG_DEBUG = $ENV{SIG_DEBUG};
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 my %bastards;
 
 #
@@ -66,7 +66,11 @@ sub handle_CHLD {
 
 	$nhandled++;
 
-	if (defined $Forks::Super::ALL_JOBS{$pid}) {
+        if ($Forks::Super::Job::Emulate::EMULATE_PID{$pid}) {
+            my $job = $Forks::Super::Job::Emulate::EMULATE_PID{$pid};
+            _preliminary_reap($job,$status);
+            Forks::Super::Job::IPC::_close_child($job);
+        } elsif (defined $Forks::Super::ALL_JOBS{$pid}) {
 	    _preliminary_reap($pid, $status);
 	} else {
 	    # There are (at least) two reasons we reach this code branch:
