@@ -7,7 +7,7 @@ use POSIX ':sys_wait_h';
 use IPC::SysV qw(IPC_PRIVATE S_IRUSR S_IWUSR IPC_CREAT IPC_NOWAIT);
 use IPC::Semaphore;
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 our $NOWAIT_YIELD_DURATION = 0.05;
 
@@ -69,18 +69,17 @@ sub _wait_on {
 
     while (1) {
 	local $! = 0;
+
 	my $nk = $partner && CORE::kill 0, $partner;
 	if (!$nk) {
-	    carp "sync::_wait_on thinks that $partner is gone ...return 3.1";
+	    carp "sync::_wait_on $$ thinks that $partner is gone ...return 3.1";
 	    $self->{skip_wait_on} = 1;
 	    delete $self->{sems};
-	    return 3.1;
+	    return $Forks::Super::Sync::SYNC_PARTNER_GONE + 0.1;
 	}
 
 	my $z = $self->{sems} && $self->{sems}->op($n, 0, &IPC_NOWAIT);
 
-#	@! = grep { $!{$_} } keys %!;
-
 	if ($z) {
 	    return 1;
 	} elsif ($!{EINVAL}) {  # semaphore was removed
@@ -98,7 +97,7 @@ sub _wait_on {
 	    carp "sync::_wait_on thinks that $partner is gone ...return 3";
 	    $self->{skip_wait_on} = 1;
 	    delete $self->{sems};
-	    return 3;
+	    return $Forks::Super::Sync::SYNC_PARTNER_GONE;
 	}
 	Time::HiRes::sleep( $NOWAIT_YIELD_DURATION );
 	waitpid -1, &WNOHANG;
