@@ -7,7 +7,7 @@ use POSIX ':sys_wait_h';
 use Win32::Semaphore;
 
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 our $NOWAIT_YIELD_DURATION = 250;
 my @RELEASE_ON_EXIT = ();
 
@@ -71,7 +71,7 @@ sub _wait_on {
 	    carp "sync::_wait_on thinks $partner is gone";
 	    $self->{skip_wait_on} = 1;
 	    delete $self->{sem};
-	    return 3;
+	    return $Forks::Super::Sync::SYNC_PARTNER_GONE;
 	}
 
 	my $z = $self->{sem} && $self->{sem}[$n]->wait($NOWAIT_YIELD_DURATION);
