@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 our $NOWAIT_YIELD_DURATION = 50; # milliseconds
 
 # Something we have to watch out for is a process dying without
@@ -61,7 +61,7 @@ sub _wait_on {
 	    $self->{skip_wait_on} = 1;
 	    $_++ for @{$self->{invalid}};
 	    # delete $self->{mutex};
-	    return 3;
+	    return $Forks::Super::Sync::SYNC_PARTNER_GONE;
 	}
 
 	my $z = $self->{mutex} && 
@@ -158,7 +158,7 @@ Forks::Super::Sync::Win32Mutex
 
 =head1 VERSION
 
-0.82
+0.83
 
 =head1 SYNOPSIS
 
